@@ -10,18 +10,20 @@ from conan.api.model import LOCAL_RECIPES_INDEX
 from conan.api.output import ConanOutput
 from conan.internal.cache.home_paths import HomePaths
 from conan.internal.api.export import cmd_export
+from conans.client.hook_manager import HookManager
 from conans.client.loader import ConanFileLoader
-from conans.errors import ConanException, PackageNotFoundException, RecipeNotFoundException, \
-    ConanReferenceDoesNotExistInDB, NotFoundException
+from conan.internal.errors import ConanReferenceDoesNotExistInDB, NotFoundException, RecipeNotFoundException, \
+    PackageNotFoundException
+from conan.errors import ConanException
 from conans.model.conf import ConfDefinition
 from conans.model.recipe_ref import RecipeReference
 from conans.util.files import load, save, rmdir, copytree_compat
 
 
-def add_local_recipes_index_remote(conan_api, remote):
+def add_local_recipes_index_remote(home_folder, remote):
     if remote.remote_type != LOCAL_RECIPES_INDEX:
         return
-    local_recipes_index_path = HomePaths(conan_api.cache_folder).local_recipes_index_path
+    local_recipes_index_path = HomePaths(home_folder).local_recipes_index_path
     repo_folder = os.path.join(local_recipes_index_path, remote.name)
 
     output = ConanOutput()
@@ -41,9 +43,9 @@ def add_local_recipes_index_remote(conan_api, remote):
     save(trim_hook, hook_content)
 
 
-def remove_local_recipes_index_remote(conan_api, remote):
+def remove_local_recipes_index_remote(home_folder, remote):
     if remote.remote_type == LOCAL_RECIPES_INDEX:
-        local_recipes_index_path = HomePaths(conan_api.cache_folder).local_recipes_index_path
+        local_recipes_index_path = HomePaths(home_folder).local_recipes_index_path
         local_recipes_index_path = os.path.join(local_recipes_index_path, remote.name)
         ConanOutput().info(f"Removing temporary files for '{remote.name}' "
                            f"local-recipes-index remote")
@@ -67,6 +69,7 @@ class RestApiClientLocalRecipesIndex:
         from conan.api.conan_api import ConanAPI
         conan_api = ConanAPI(local_recipes_index_path)
         self._app = ConanApp(conan_api)
+        self._hook_manager = HookManager(HomePaths(conan_api.home_folder).hooks_path)
         self._layout = _LocalRecipesIndexLayout(repo_folder)
 
     def call_method(self, method_name, *args, **kwargs):
@@ -99,7 +102,7 @@ class RestApiClientLocalRecipesIndex:
         raise ConanException(f"Remote local-recipes-index '{self._remote.name}' doesn't support "
                              "authentication")
 
-    def check_credentials(self):
+    def check_credentials(self, force_auth=False):
         raise ConanException(f"Remote local-recipes-index '{self._remote.name}' doesn't support upload")
 
     def search(self, pattern=None):
@@ -149,8 +152,8 @@ class RestApiClientLocalRecipesIndex:
         sys.stderr = StringIO()
         try:
             global_conf = ConfDefinition()
-            new_ref, _ = cmd_export(self._app, global_conf, conanfile_path, ref.name,
-                                    str(ref.version), None, None, remotes=[self._remote])
+            new_ref, _ = cmd_export(self._app, self._hook_manager, global_conf, conanfile_path,
+                                    ref.name, str(ref.version), None, None, remotes=[self._remote])
         except Exception as e:
             raise ConanException(f"Error while exporting recipe from remote: {self._remote.name}\n"
                                  f"{str(e)}")
@@ -197,6 +200,16 @@ class _LocalRecipesIndexLayout:
         ret = []
         excluded = set()
 
+        original_pattern = pattern
+        try:
+            pattern_ref = RecipeReference.loads(pattern)
+            # We don't care about user/channel for now, we'll check for those below,
+            # just add all candidates for now
+            pattern = f"{pattern_ref.name}/{pattern_ref.version}"
+        except:
+            # pattern = pattern
+            pass
+
         loader = ConanFileLoader(None)
         for r in recipes:
             if r.startswith("."):
@@ -229,7 +242,9 @@ class _LocalRecipesIndexLayout:
                     ref.channel = recipe.channel
                 except Exception as e:
                     ConanOutput().warning(f"Couldn't load recipe {conanfile}: {e}")
-                ret.append(ref)
+                if ref.matches(original_pattern, None):
+                    # Check again the pattern with the user/channel
+                    ret.append(ref)
         if excluded:
             ConanOutput().warning(f"Excluding recipes not Conan 2.0 ready: {', '.join(excluded)}")
         return ret
